@@ -199,8 +199,8 @@ const ObjectImpType *BezierImp::stype()
     static const ObjectImpType B(Parent::stype(),
                                  "bezier",
                                  kli18n("Bézier Curve"),
-                                 I18N_NOOP("Select this Bézier Curve"),
-                                 I18N_NOOP("Select Bézier Curve %1"),
+                                 kli18n("Select this Bézier Curve"),
+                                 kli18n("Select Bézier Curve %1"),
                                  kli18n("Remove a Bézier Curve"),
                                  kli18n("Add a Bézier Curve"),
                                  kli18n("Move a Bézier Curve"),
@@ -216,8 +216,8 @@ const ObjectImpType *BezierImp::stype2()
     static const ObjectImpType B3(BezierImp::stype(),
                                   "bezier_quadratic",
                                   kli18n("Bézier Quadratic"),
-                                  I18N_NOOP("Select this Bézier Quadratic"),
-                                  I18N_NOOP("Select Bézier Quadratic %1"),
+                                  kli18n("Select this Bézier Quadratic"),
+                                  kli18n("Select Bézier Quadratic %1"),
                                   kli18n("Remove a Bézier Quadratic"),
                                   kli18n("Add a Bézier Quadratic"),
                                   kli18n("Move a Bézier Quadratic"),
@@ -233,8 +233,8 @@ const ObjectImpType *BezierImp::stype3()
     static const ObjectImpType B4(BezierImp::stype(),
                                   "bezier_cubic",
                                   kli18n("Bézier Cubic"),
-                                  I18N_NOOP("Select this Bézier Cubic"),
-                                  I18N_NOOP("Select Bézier Cubic %1"),
+                                  kli18n("Select this Bézier Cubic"),
+                                  kli18n("Select Bézier Cubic %1"),
                                   kli18n("Remove a Bézier Cubic"),
                                   kli18n("Add a Bézier Cubic"),
                                   kli18n("Move a Bézier Cubic"),
@@ -488,8 +488,8 @@ const ObjectImpType *RationalBezierImp::stype()
     static const ObjectImpType R(Parent::stype(),
                                  "rational_bezier",
                                  kli18n("Rational Bézier Curve"),
-                                 I18N_NOOP("Select this Rational Bézier Curve"),
-                                 I18N_NOOP("Select Rational Bézier Curve %1"),
+                                 kli18n("Select this Rational Bézier Curve"),
+                                 kli18n("Select Rational Bézier Curve %1"),
                                  kli18n("Remove a Rational Bézier Curve"),
                                  kli18n("Add a Rational Bézier Curve"),
                                  kli18n("Move a Rational Bézier Curve"),
@@ -505,8 +505,8 @@ const ObjectImpType *RationalBezierImp::stype2()
     static const ObjectImpType R3(BezierImp::stype(),
                                   "rational_bezier_quadratic",
                                   kli18n("Rational Bézier Quadratic"),
-                                  I18N_NOOP("Select this Rational Bézier Quadratic"),
-                                  I18N_NOOP("Select Rational Bézier Quadratic %1"),
+                                  kli18n("Select this Rational Bézier Quadratic"),
+                                  kli18n("Select Rational Bézier Quadratic %1"),
                                   kli18n("Remove a Rational Bézier Quadratic"),
                                   kli18n("Add a Rational Bézier Quadratic"),
                                   kli18n("Move a Rational Bézier Quadratic"),
@@ -522,8 +522,8 @@ const ObjectImpType *RationalBezierImp::stype3()
     static const ObjectImpType R4(BezierImp::stype(),
                                   "rational_bezier_cubic",
                                   kli18n("Rational Bézier Cubic"),
-                                  I18N_NOOP("Select this Rational Bézier Cubic"),
-                                  I18N_NOOP("Select Rational Bézier Cubic %1"),
+                                  kli18n("Select this Rational Bézier Cubic"),
+                                  kli18n("Select Rational Bézier Cubic %1"),
                                   kli18n("Remove a Rational Bézier Cubic"),
                                   kli18n("Add a Rational Bézier Cubic"),
                                   kli18n("Move a Rational Bézier Cubic"),
