@@ -184,8 +184,8 @@ const ObjectImpType *LocusImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "locus",
                                  kli18n("locus"),
-                                 I18N_NOOP("Select this locus"),
-                                 I18N_NOOP("Select locus %1"),
+                                 kli18n("Select this locus"),
+                                 kli18n("Select locus %1"),
                                  kli18n("Remove a Locus"),
                                  kli18n("Add a Locus"),
                                  kli18n("Move a Locus"),
