@@ -610,8 +610,8 @@ const ObjectImpType *AbstractPolygonImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "abstractpolygon",
                                  kli18n("polygon"),
-                                 I18N_NOOP("Select this polygon"),
-                                 nullptr,
+                                 kli18n("Select this polygon"),
+                                 KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
@@ -626,8 +626,8 @@ const ObjectImpType *FilledPolygonImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "polygon",
                                  kli18n("polygon"),
-                                 I18N_NOOP("Select this polygon"),
-                                 I18N_NOOP("Select polygon %1"),
+                                 kli18n("Select this polygon"),
+                                 kli18n("Select polygon %1"),
                                  kli18n("Remove a Polygon"),
                                  kli18n("Add a Polygon"),
                                  kli18n("Move a Polygon"),
@@ -643,8 +643,8 @@ const ObjectImpType *ClosedPolygonalImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "closedpolygonal",
                                  kli18n("closed polygonal curve"),
-                                 I18N_NOOP("Select this closed polygonal curve"),
-                                 I18N_NOOP("Select closed polygonal curve %1"),
+                                 kli18n("Select this closed polygonal curve"),
+                                 kli18n("Select closed polygonal curve %1"),
                                  kli18n("Remove a closed polygonal curve"),
                                  kli18n("Add a closed polygonal curve"),
                                  kli18n("Move a closed polygonal curve"),
@@ -660,8 +660,8 @@ const ObjectImpType *OpenPolygonalImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "polygonal",
                                  kli18n("polygonal curve"),
-                                 I18N_NOOP("Select this polygonal curve"),
-                                 I18N_NOOP("Select polygonal curve %1"),
+                                 kli18n("Select this polygonal curve"),
+                                 kli18n("Select polygonal curve %1"),
                                  kli18n("Remove a polygonal curve"),
                                  kli18n("Add a polygonal curve"),
                                  kli18n("Move a polygonal curve"),
@@ -677,8 +677,8 @@ const ObjectImpType *FilledPolygonImp::stype3()
     static const ObjectImpType t3(FilledPolygonImp::stype(),
                                   "triangle",
                                   kli18n("triangle"),
-                                  I18N_NOOP("Select this triangle"),
-                                  I18N_NOOP("Select triangle %1"),
+                                  kli18n("Select this triangle"),
+                                  kli18n("Select triangle %1"),
                                   kli18n("Remove a Triangle"),
                                   kli18n("Add a Triangle"),
                                   kli18n("Move a Triangle"),
@@ -694,8 +694,8 @@ const ObjectImpType *FilledPolygonImp::stype4()
     static const ObjectImpType t4(FilledPolygonImp::stype(),
                                   "quadrilateral",
                                   kli18n("quadrilateral"),
-                                  I18N_NOOP("Select this quadrilateral"),
-                                  I18N_NOOP("Select quadrilateral %1"),
+                                  kli18n("Select this quadrilateral"),
+                                  kli18n("Select quadrilateral %1"),
                                   kli18n("Remove a Quadrilateral"),
                                   kli18n("Add a Quadrilateral"),
                                   kli18n("Move a Quadrilateral"),
